Testdata for tornadoplots from one by one sensitivities (design matrix)
distributions: contains design matrix on fmu standard format in excel and .csv format
results: contains in place volumes exported from RMS in fmu standard csv format
config: contains yaml config files for add_webviz_tornado_onebyone.py